@@ -42,9 +42,9 @@
 #include <kgenericfactory.h>
 #include <ktextedit.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 
 #include "containerfactory.h"
 #include "container.h"
@@ -56,7 +56,7 @@
 #include "widgetlibrary.h"
 #include <formeditor/utils.h>
 
-#if KDE_VERSION < KDE_MAKE_VERSION(3,1,9)
+#if TDE_VERSION < TDE_MAKE_VERSION(3,1,9)
 # define KInputDialog TQInputDialog
 # include <tqinputdialog.h>
 # include <tqlineedit.h>
@@ -367,7 +367,7 @@ ContainerFactory::ContainerFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wTabWidget = new KFormDesigner::WidgetInfo(this);
 	wTabWidget->setPixmap("tabwidget");
 	wTabWidget->setClassName("KFDTabWidget");
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 	wTabWidget->addAlternateClassName("KTabWidget");
 	wTabWidget->addAlternateClassName(TQTABWIDGET_OBJECT_NAME_STRING);
 //tmp:	wTabWidget->setSavingName(TQTABWIDGET_OBJECT_NAME_STRING);
@@ -518,7 +518,7 @@ ContainerFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 	else if(c == "KFDTabWidget")
 	{
 		KFDTabWidget *tab = new KFDTabWidget(p, n);
-#if defined(USE_KTabWidget) && KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
+#if defined(USE_KTabWidget) && TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 		tab->setTabReorderingEnabled(true);
 		connect(tab, TQT_SIGNAL(movedTab(int,int)), this, TQT_SLOT(reorderTabs(int,int)));
 #endif
@@ -686,11 +686,11 @@ ContainerFactory::createMenuActions(const TQCString &classname, TQWidget *w, TQP
 		if(stack->childrenListObject().count() == 4) // == the stack has only one page
 			menu->setItemEnabled(id, false);
 
-		id = menu->insertItem(SmallIconSet("next"), i18n("Jump to Next Page"), this, TQT_SLOT(nextStackPage()));
+		id = menu->insertItem(SmallIconSet("go-next"), i18n("Jump to Next Page"), this, TQT_SLOT(nextStackPage()));
 		if(!stack->widget(stack->id(stack->visibleWidget())+1))
 			menu->setItemEnabled(id, false);
 
-		id = menu->insertItem(SmallIconSet("previous"), i18n("Jump to Previous Page"), this, TQT_SLOT(prevStackPage()));
+		id = menu->insertItem(SmallIconSet("go-previous"), i18n("Jump to Previous Page"), this, TQT_SLOT(prevStackPage()));
 		if(!stack->widget(stack->id(stack->visibleWidget()) -1) )
 			menu->setItemEnabled(id, false);
 		return true;
@@ -857,7 +857,7 @@ void ContainerFactory::renameTabPage()
 	bool ok;
 
 	TQString name = KInputDialog::getText(i18n("New Page Title"), i18n("Enter a new title for the current page:"),
-#if KDE_VERSION < KDE_MAKE_VERSION(3,1,9)
+#if TDE_VERSION < TDE_MAKE_VERSION(3,1,9)
 	       TQLineEdit::Normal,
 #endif
 	       tab->tabLabel(w), &ok, w->topLevelWidget());
