@@ -31,28 +31,28 @@
 #include <tqvaluevector.h>
 #include <tqvbox.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstdaction.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kxmlguiclient.h>
-#include <kmainwindow.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <kstyle.h>
-#include <kactionclasses.h>
-#include <kapplication.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
+#include <tdemainwindow.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
+#include <tdestyle.h>
+#include <tdeactionclasses.h>
+#include <tdeapplication.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
 #include <kdialogbase.h>
 #include <ktextedit.h>
 #include <ktabwidget.h>
-#include <kfontdialog.h>
+#include <tdefontdialog.h>
 
-#include <kdeversion.h>
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9) && !defined(TQ_WS_WIN)
-# include <kactioncollection.h>
+#include <tdeversion.h>
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9) && !defined(TQ_WS_WIN)
+# include <tdeactioncollection.h>
 #endif
 
 #include "widgetpropertyset.h"
@@ -116,13 +116,13 @@ FormManager::FormManager(TQObject *parent, int options, const char *name)
 {
 	Q_UNUSED(options);
 #ifdef KEXI_STANDALONE
-	KGlobal::locale()->insertCatalogue("standalone_kformdesigner");
+	TDEGlobal::locale()->insertCatalogue("standalone_kformdesigner");
 #else
-	KGlobal::locale()->insertCatalogue("kformdesigner");
+	TDEGlobal::locale()->insertCatalogue("kformdesigner");
 #endif
 
 	connect( kapp, TQT_SIGNAL( settingsChanged(int) ), TQT_SLOT( slotSettingsChanged(int) ) );
-	slotSettingsChanged(KApplication::SETTINGS_SHORTCUTS);
+	slotSettingsChanged(TDEApplication::SETTINGS_SHORTCUTS);
 
 //moved to createWidgetLibrary()	m_lib = new WidgetLibrary(this, supportedFactoryGroups);
 	m_propSet = new WidgetPropertySet(this);
@@ -192,7 +192,7 @@ FormManager::setObjectTreeView(ObjectTreeView *treeview)
 }
 
 ActionList
-FormManager::createActions(WidgetLibrary *lib, KActionCollection* collection, KXMLGUIClient* client)
+FormManager::createActions(WidgetLibrary *lib, TDEActionCollection* collection, KXMLGUIClient* client)
 {
 	m_collection = collection;
 
@@ -201,8 +201,8 @@ FormManager::createActions(WidgetLibrary *lib, KActionCollection* collection, KX
 	if (m_options & HideSignalSlotConnections)
 		m_dragConnection = 0;
 	else {
-		m_dragConnection = new KToggleAction(i18n("Connect Signals/Slots"),
-			"signalslot", KShortcut(0), this, TQT_SLOT(startCreatingConnection()), m_collection,
+		m_dragConnection = new TDEToggleAction(i18n("Connect Signals/Slots"),
+			"signalslot", TDEShortcut(0), this, TQT_SLOT(startCreatingConnection()), m_collection,
 			"drag_connection");
 		//to be exclusive with any 'widget' action
 		m_dragConnection->setExclusiveGroup("LibActionWidgets");
@@ -210,23 +210,23 @@ FormManager::createActions(WidgetLibrary *lib, KActionCollection* collection, KX
 		actions.append(m_dragConnection);
 	}
 
-	m_pointer = new KToggleAction(i18n("Pointer"), "mouse_pointer", KShortcut(0), 
+	m_pointer = new TDEToggleAction(i18n("Pointer"), "mouse_pointer", TDEShortcut(0), 
 		this, TQT_SLOT(slotPointerClicked()), m_collection, "pointer");
 	m_pointer->setExclusiveGroup("LibActionWidgets"); //to be exclusive with any 'widget' action
 	m_pointer->setChecked(true);
 	actions.append(m_pointer);
 
-	m_snapToGrid = new KToggleAction(i18n("Snap to Grid"), TQString(), KShortcut(0), 
+	m_snapToGrid = new TDEToggleAction(i18n("Snap to Grid"), TQString(), TDEShortcut(0), 
 		0, 0, m_collection, "snap_to_grid");
 	m_snapToGrid->setChecked(true);
 	actions.append(m_snapToGrid);
 
 	// Create the Style selection action (with a combo box in toolbar and submenu items)
-	KSelectAction *m_style = new KSelectAction( i18n("Style"), KShortcut(0), 
+	TDESelectAction *m_style = new TDESelectAction( i18n("Style"), TDEShortcut(0), 
 		this, TQT_SLOT(slotStyle()), m_collection, "change_style");
 	m_style->setEditable(false);
 
-	KGlobal::config()->setGroup("General");
+	TDEGlobal::config()->setGroup("General");
 	TQString currentStyle = TQString::fromLatin1(kapp->style().name()).lower();
 	const TQStringList styles = TQStyleFactory::keys();
 	m_style->setItems(styles);
@@ -501,7 +501,7 @@ FormManager::windowChanged(TQWidget *w)
 			{
 #ifndef KFD_NO_STYLES
 				// update the 'style' action
-				KSelectAction *m_style = (KSelectAction*)m_collection->action("change_style", "KSelectAction");
+				TDESelectAction *m_style = (TDESelectAction*)m_collection->action("change_style", "TDESelectAction");
 				const TQString currentStyle = form->widget()->style().name();
 				const TQStringList styles = m_style->items();
 
@@ -544,7 +544,7 @@ FormManager::windowChanged(TQWidget *w)
 			{
 #ifndef KFD_NO_STYLES
 				// update the 'style' action
-				KSelectAction *m_style = (KSelectAction*)m_collection->action("change_style", "KSelectAction");
+				TDESelectAction *m_style = (TDESelectAction*)m_collection->action("change_style", "TDESelectAction");
 				const TQString currentStyle = form->widget()->style().name();
 				const TQStringList styles = m_style->items();
 
@@ -787,7 +787,7 @@ FormManager::setInsertPoint(const TQPoint &p)
 void
 FormManager::createSignalMenu(TQWidget *w)
 {
-	m_sigSlotMenu = new KPopupMenu();
+	m_sigSlotMenu = new TDEPopupMenu();
 	m_sigSlotMenu->insertTitle(SmallIcon("connection"), i18n("Signals"));
 
 	TQStrList list = w->metaObject()->signalNames(true);
@@ -808,7 +808,7 @@ FormManager::createSignalMenu(TQWidget *w)
 void
 FormManager::createSlotMenu(TQWidget *w)
 {
-	m_sigSlotMenu = new KPopupMenu();
+	m_sigSlotMenu = new TDEPopupMenu();
 	m_sigSlotMenu->insertTitle(SmallIcon("connection"), i18n("Slots"));
 
 	TQString signalArg( m_connection->signal().remove( TQRegExp(".*[(]|[)]") ) );
@@ -853,7 +853,7 @@ FormManager::createContextMenu(TQWidget *w, Container *container, bool popupAtCu
 //	TQValueVector<int> menuIds();
 
 	if (!m_popup) {
-		m_popup = new KPopupMenu();
+		m_popup = new TDEPopupMenu();
 	}
 	else {
 		m_popup->clear();
@@ -872,7 +872,7 @@ FormManager::createContextMenu(TQWidget *w, Container *container, bool popupAtCu
 		m_popup->insertTitle(SmallIcon("multiple_obj"), i18n("Multiple Widgets")
 		+ TQString(" (%1)").arg(widgetsCount));
 
-	KAction *a;
+	TDEAction *a;
 #define PLUG_ACTION(_name, forceVisible) \
 	{ a = action(_name); \
 	if (a && (forceVisible || a->isEnabled())) { \
@@ -903,7 +903,7 @@ FormManager::createContextMenu(TQWidget *w, Container *container, bool popupAtCu
 		if (separatorNeeded)
 			m_popup->insertSeparator();
 
-		KPopupMenu *sub = new KPopupMenu(w);
+		TDEPopupMenu *sub = new TDEPopupMenu(w);
 		TQWidget *buddy = ((TQLabel*)w)->buddy();
 
 		sub->insertItem(i18n("No Buddy"), MenuNoBuddy);
@@ -936,7 +936,7 @@ FormManager::createContextMenu(TQWidget *w, Container *container, bool popupAtCu
 			m_popup->insertSeparator();
 
 		// We create the signals menu
-		KPopupMenu *sigMenu = new KPopupMenu();
+		TDEPopupMenu *sigMenu = new TDEPopupMenu();
 		TQStrList list = w->metaObject()->signalNames(true);
 		TQStrListIterator it(list);
 		for(; it.current() != 0; ++it)
@@ -1206,7 +1206,7 @@ FormManager::slotStyle()
 	if(!activeForm())
 		return;
 
-	KSelectAction *m_style = (KSelectAction*)m_collection->action("change_style", "KSelectAction");
+	TDESelectAction *m_style = (TDESelectAction*)m_collection->action("change_style", "TDESelectAction");
 	TQString style = m_style->currentText();
 	activeForm()->widget()->setStyle( style );
 
@@ -1459,8 +1459,8 @@ FormManager::showFormUICode()
 void
 FormManager::slotSettingsChanged(int category)
 {
-	if (category==KApplication::SETTINGS_SHORTCUTS) {
-		m_contextMenuKey = KGlobalSettings::contextMenuKey();
+	if (category==TDEApplication::SETTINGS_SHORTCUTS) {
+		m_contextMenuKey = TDEGlobalSettings::contextMenuKey();
 	}
 }
 
@@ -1684,26 +1684,26 @@ FormManager::changeFont()
 		//single widget's settings
 		widget = widgetsWithFontProperty.first();
 		KoProperty::Property &fontProp = m_propSet->property("font");
-		if (TQDialog::Accepted != KFontDialog::getFont(font, false, m_active->widget()))
+		if (TQDialog::Accepted != TDEFontDialog::getFont(font, false, m_active->widget()))
 			return;
 		fontProp = font;
 		return;
 	}
 	//multiple widgets
 	int diffFlags=0;
-	if (TQDialog::Accepted != KFontDialog::getFontDiff(font, diffFlags, false, m_active->widget())
+	if (TQDialog::Accepted != TDEFontDialog::getFontDiff(font, diffFlags, false, m_active->widget())
 		|| 0==diffFlags)
 		return;
 	//update font
 	for (WidgetListIterator it(widgetsWithFontProperty); (widget = it.current()); ++it) {
 		TQFont prevFont( widget->font() );
-		if (diffFlags & KFontChooser::FontDiffFamily)
+		if (diffFlags & TDEFontChooser::FontDiffFamily)
 			prevFont.setFamily( font.family() );
-		if (diffFlags & KFontChooser::FontDiffStyle) {
+		if (diffFlags & TDEFontChooser::FontDiffStyle) {
 			prevFont.setBold( font.bold() );
 			prevFont.setItalic( font.italic() );
 		}
-		if (diffFlags & KFontChooser::FontDiffSize)
+		if (diffFlags & TDEFontChooser::FontDiffSize)
 			prevFont.setPointSize( font.pointSize() );
 /*! @todo this modification is not added to UNDO BUFFER:
           do it when KoProperty::Set supports multiple selections */
