@@ -20,12 +20,12 @@
 #ifndef KFORMDESIGNER_MAINWINDOW_H
 #define KFORMDESIGNER_MAINWINDOW_H
 
-#include <kparts/mainwindow.h>
+#include <tdeparts/mainwindow.h>
 
 class KFDMainWindow : public KParts::MainWindow
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 	public:
 		KFDMainWindow();
