@@ -22,10 +22,10 @@
 #include <core/keximainwindow.h>
 #include <kexiutils/utils.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kfontdialog.h>
+#include <tdelocale.h>
+#include <tdefontdialog.h>
 #include <kurllabel.h>
 #include <kdebug.h>
 
@@ -63,7 +63,7 @@ KexiSimplePrintingSettings KexiSimplePrintingSettings::load()
 {
 	KexiSimplePrintingSettings settings; //this will set defaults
 
-	KConfig *config = kapp->config();
+	TDEConfig *config = kapp->config();
 	config->setGroup("Simple Printing");
 	if (config->hasKey("pageTitleFont"))
 		settings.pageTitleFont = config->readFontEntry("pageTitleFont");
@@ -95,7 +95,7 @@ KexiSimplePrintingSettings KexiSimplePrintingSettings::load()
 
 void KexiSimplePrintingSettings::save()
 {
-	KConfig *config = kapp->config();
+	TDEConfig *config = kapp->config();
 	config->setGroup("Simple Printing");
 	config->writeEntry( "pageTitleFont", pageTitleFont );
 	config->writeEntry( "pageFormat", KoPageFormat::formatString( pageLayout.format ) );
@@ -278,7 +278,7 @@ void KexiSimplePrintingEngine::paintPage(int pageNumber, TQPainter& painter, boo
 		}
 		painter.setFont(m_mainFont);
 
-		m_dateTimeText = KGlobal::locale()->formatDateTime(TQDateTime::currentDateTime(),
+		m_dateTimeText = TDEGlobal::locale()->formatDateTime(TQDateTime::currentDateTime(),
 			true, false);
 		m_dateTimeWidth = painter.fontMetrics().width(m_dateTimeText+"   ");
 		m_mainLineSpacing = painter.fontMetrics().lineSpacing();
@@ -432,23 +432,23 @@ void KexiSimplePrintingEngine::paintRecord(TQPainter& painter, KexiTableItem *it
 		else if (ftype==KexiDB::Field::DateTime) {
 			TQDateTime dt(v.toDateTime());
 			if (dt.isValid())
-				text = KGlobal::locale()->formatDateTime(dt);
+				text = TDEGlobal::locale()->formatDateTime(dt);
 		}
 //! todo inherit format
 		else if (ftype==KexiDB::Field::Date) {
 			TQDate date(v.toDate());
 			if (date.isValid())
-				text = KGlobal::locale()->formatDate(date, true/*short*/);
+				text = TDEGlobal::locale()->formatDate(date, true/*short*/);
 		}
 //! todo inherit format
 		else if (ftype==KexiDB::Field::Time) {
 			TQTime time(v.toTime());
 			if (time.isValid())
-				text = KGlobal::locale()->formatTime(time);
+				text = TDEGlobal::locale()->formatTime(time);
 		}
 //! todo currency, decimal...
 		else if (ci->field->isFPNumericType())
-			text = KGlobal::locale()->formatNumber(v.toDouble());
+			text = TDEGlobal::locale()->formatNumber(v.toDouble());
 		else if (ftype==KexiDB::Field::Boolean)
 			text = v.toBool() 
 				? i18n("Boolean Yes (true)","Yes") : i18n("Boolean No (false)", "No");
