@@ -8,15 +8,15 @@
 
 
 #include <KoFactory.h>
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 
-class KInstance;
+class TDEInstance;
 
 
 class KugarFactory : public KoFactory
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     KugarFactory( TQObject* parent = 0, const char* name = 0 );
     ~KugarFactory();
@@ -25,13 +25,13 @@ public:
                                             TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument",
                                             const TQStringList &args = TQStringList() );
 
-    static KInstance* global();
+    static TDEInstance* global();
 
-    // _Creates_ a KAboutData but doesn't keep ownership
-    static KAboutData* aboutData();
+    // _Creates_ a TDEAboutData but doesn't keep ownership
+    static TDEAboutData* aboutData();
 private:
-    static KInstance* s_instance;
-    static KAboutData* s_aboutdata;
+    static TDEInstance* s_instance;
+    static TDEAboutData* s_aboutdata;
 };
 
 #endif
