@@ -104,7 +104,7 @@ class KoOasisSettings;
 class KWDocument : public KoDocument, public KoTextZoomHandler
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     TQ_PROPERTY( double ptColumnWidth READ ptColumnWidth )
     TQ_PROPERTY( double ptColumnSpacing READ ptColumnSpacing )
     TQ_PROPERTY( double gridX READ gridX WRITE setGridX )
@@ -730,7 +730,7 @@ public:
     TQStringList listOfBookmarkName(KWViewMode * viewMode) const;
 
     void paragraphDeleted( KoTextParag *parag, KWFrameSet *frm);
-    void paragraphModified(KoTextParag* parag, int /*KoTextParag::ParagModifyType*/ type, int start, int lenght);
+    void paragraphModified(KoTextParag* parag, int /*KoTextParag::ParagModifyType*/ type, int start, int length);
 
     void initBookmarkList();
     void loadImagesFromStore( KoStore *store );
