@@ -27,10 +27,10 @@
 #include <KoStoreDevice.h>
 #include <KoXmlWriter.h>
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 
 #include <tqobjectlist.h>
 #include <tqdatetime.h>
@@ -217,9 +217,9 @@ KoDocumentInfoAuthor::~KoDocumentInfoAuthor()
 }
 void KoDocumentInfoAuthor::initParameters()
 {
-    KConfig* config = KoGlobal::kofficeConfig();
+    TDEConfig* config = KoGlobal::kofficeConfig();
     if ( config->hasGroup( "Author" ) ) {
-        KConfigGroupSaver cgs( config, "Author" );
+        TDEConfigGroupSaver cgs( config, "Author" );
         m_telephoneHome=config->readEntry( "telephone" );
         m_telephoneWork=config->readEntry( "telephone-work" );
         m_fax=config->readEntry( "fax" );
@@ -229,7 +229,7 @@ void KoDocumentInfoAuthor::initParameters()
         m_street=config->readEntry( "street" );
     }
 
-  m_emailCfg = new KConfig( "emaildefaults", true );
+  m_emailCfg = new TDEConfig( "emaildefaults", true );
   m_emailCfg->setGroup( "Defaults" );
   TQString group = m_emailCfg->readEntry("Profile","Default");
   m_emailCfg->setGroup(TQString("PROFILE_%1").arg(group));
@@ -831,7 +831,7 @@ TQString KoDocumentInfoAbout::editingCycles() const
 TQString KoDocumentInfoAbout::creationDate() const
 {
     if ( m_creationDate.isValid() )
-        return KGlobal::locale()->formatDateTime( m_creationDate );
+        return TDEGlobal::locale()->formatDateTime( m_creationDate );
     else
         return TQString();
 }
@@ -839,7 +839,7 @@ TQString KoDocumentInfoAbout::creationDate() const
 TQString KoDocumentInfoAbout::modificationDate() const
 {
     if ( m_modificationDate.isValid() )
-        return KGlobal::locale()->formatDateTime( m_modificationDate );
+        return TDEGlobal::locale()->formatDateTime( m_modificationDate );
     else
         return TQString();
 }
