@@ -17,7 +17,7 @@
 */
 
 #include <tqmetaobject.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <kmimetype.h>
 #include <KoFilterChain.h>
 #include <KoQueryTrader.h>
@@ -806,8 +806,8 @@ namespace KOffice {
         TQValueList<KoDocumentEntry>::ConstIterator partEnd( parts.end() );
 
         while ( partIt != partEnd ) {
-            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
-            nativeMimeTypes += ( *partIt ).service()->property( "X-KDE-NativeMimeType" ).toString();
+            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-TDE-ExtraNativeMimeTypes" ).toStringList();
+            nativeMimeTypes += ( *partIt ).service()->property( "X-TDE-NativeMimeType" ).toString();
             TQStringList::ConstIterator it = nativeMimeTypes.begin();
             TQStringList::ConstIterator end = nativeMimeTypes.end();
             for ( ; it != end; ++it )
@@ -897,8 +897,8 @@ namespace KOffice {
 
         // Be sure that v gets initialized correctly
         while ( !v && partIt != partEnd ) {
-            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
-            nativeMimeTypes += ( *partIt ).service()->property( "X-KDE-NativeMimeType" ).toString();
+            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-TDE-ExtraNativeMimeTypes" ).toStringList();
+            nativeMimeTypes += ( *partIt ).service()->property( "X-TDE-NativeMimeType" ).toString();
             TQStringList::ConstIterator it = nativeMimeTypes.begin();
             TQStringList::ConstIterator end = nativeMimeTypes.end();
             for ( ; !v && it != end; ++it )
@@ -911,8 +911,8 @@ namespace KOffice {
 
         // Now we try to find the "cheapest" KOffice vertex
         while ( partIt != partEnd ) {
-            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
-            nativeMimeTypes += ( *partIt ).service()->property( "X-KDE-NativeMimeType" ).toString();
+            TQStringList nativeMimeTypes = ( *partIt ).service()->property( "X-TDE-ExtraNativeMimeTypes" ).toStringList();
+            nativeMimeTypes += ( *partIt ).service()->property( "X-TDE-NativeMimeType" ).toString();
             TQStringList::ConstIterator it = nativeMimeTypes.begin();
             TQStringList::ConstIterator end = nativeMimeTypes.end();
             for ( ; !v && it != end; ++it ) {
