@@ -43,11 +43,11 @@
 #include <tqstylesheet.h>
 
 // KDE includes.
-#include <kapplication.h>
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <dcopclient.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <ktrader.h>
 #include <kdebug.h>
 
@@ -113,7 +113,7 @@ KoSpeaker::KoSpeaker()
     Q_ASSERT(!KSpkr);
     KSpkr = this;
     d = new KoSpeakerPrivate();
-    readConfig(KGlobal::config());
+    readConfig(TDEGlobal::config());
 }
 
 KoSpeaker::~KoSpeaker()
@@ -170,7 +170,7 @@ void KoSpeaker::queueSpeech(const TQString& msg, const TQString& langCode /*= TQ
     // If no language code given, assume desktop setting.
     TQString languageCode = langCode;
     if (langCode.isEmpty())
-        languageCode = KGlobal::locale()->language();
+        languageCode = TDEGlobal::locale()->language();
     // kdDebug() << "KoSpeaker::queueSpeech:languageCode = " << languageCode << endl;
     // If KTTSD version is 0.3.5 or later, we can use the appendText method to submit a
     // single, multi-part text job.  Otherwise, must submit separate text jobs.
@@ -193,7 +193,7 @@ void KoSpeaker::startSpeech()
         startText(d->m_jobNums[i]);
 }
 
-void KoSpeaker::readConfig(KConfig* config)
+void KoSpeaker::readConfig(TDEConfig* config)
 {
     delete d->m_timer;
     d->m_timer = 0;
@@ -475,7 +475,7 @@ bool KoSpeaker::sayWidget(const TQString& msg)
 
 /*static*/ bool KoSpeaker::isKttsdInstalled()
 {
-     KTrader::OfferList offers = KTrader::self()->query("DCOP/Text-to-Speech", "Name == 'KTTSD'");
+     TDETrader::OfferList offers = TDETrader::self()->query("DCOP/Text-to-Speech", "Name == 'KTTSD'");
      return (offers.count() > 0);
 }
 
