@@ -20,20 +20,20 @@
 
 
 #include "tkcoloractions.h"
-#include "tktoolbarbutton.h"
+#include "ttdetoolbarbutton.h"
 
 #include <tqlayout.h>
 #include <kcolordialog.h>
-#include <ktoolbar.h>
+#include <tdetoolbar.h>
 #include <tqpainter.h>
 #include <tqtooltip.h>
 #include <tqwhatsthis.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <tqapplication.h>
 
 TKColorPopupMenu::TKColorPopupMenu( TQWidget* parent, const char* name )
-: KPopupMenu(parent,name)
+: TDEPopupMenu(parent,name)
 {
 }
 
@@ -46,10 +46,10 @@ void TKColorPopupMenu::updateItemSize()
   styleChange(style());
 }
 /****************************************************************************************/
-class TKSelectColorActionPrivate
+class TTDESelectColorActionPrivate
 {
 public:
-    TKSelectColorActionPrivate()
+    TTDESelectColorActionPrivate()
     {
     }
     bool defaultColorMenu;
@@ -57,10 +57,10 @@ public:
 };
 
 
-TKSelectColorAction::TKSelectColorAction( const TQString& text, Type type, TQObject* parent, const char* name, bool menuDefaultColor )
-: TKAction(parent,name)
+TTDESelectColorAction::TTDESelectColorAction( const TQString& text, Type type, TQObject* parent, const char* name, bool menuDefaultColor )
+: TTDEAction(parent,name)
 {
-    d=new TKSelectColorActionPrivate();
+    d=new TTDESelectColorActionPrivate();
     d->defaultColorMenu=menuDefaultColor;
     d->defaultColor=TQColor();
     setText(text);
@@ -68,12 +68,12 @@ TKSelectColorAction::TKSelectColorAction( const TQString& text, Type type, TQObj
     init();
 }
 
-TKSelectColorAction::TKSelectColorAction( const TQString& text, Type type,
+TTDESelectColorAction::TTDESelectColorAction( const TQString& text, Type type,
                                           TQObject* receiver, const char* slot,
                                           TQObject* parent, const char* name, bool menuDefaultColor)
-: TKAction(parent,name)
+: TTDEAction(parent,name)
 {
-    d=new TKSelectColorActionPrivate();
+    d=new TTDESelectColorActionPrivate();
     d->defaultColorMenu=menuDefaultColor;
     d->defaultColor=TQColor();
     setText(text);
@@ -82,7 +82,7 @@ TKSelectColorAction::TKSelectColorAction( const TQString& text, Type type,
     init();
 }
 
-void TKSelectColorAction::init()
+void TTDESelectColorAction::init()
 {
   m_pStandardColor = new TKColorPanel();
   m_pRecentColor = new TKColorPanel();
@@ -129,44 +129,44 @@ void TKSelectColorAction::init()
   connect(m_pRecentColor,TQT_SIGNAL(sizeChanged()),m_pMenu,TQT_SLOT(updateItemSize()));
 }
 
-TKSelectColorAction::~TKSelectColorAction()
+TTDESelectColorAction::~TTDESelectColorAction()
 {
   delete m_pMenu;
   delete d;
 }
 
-void TKSelectColorAction::initToolBarButton(TKToolBarButton* b)
+void TTDESelectColorAction::initToolBarButton(TTDEToolBarButton* b)
 {
   TQWhatsThis::add( b, whatsThis() );
-  TKAction::initToolBarButton(b);
+  TTDEAction::initToolBarButton(b);
   b->setDelayedPopup( popupMenu() );
   updatePixmap(b);
   updatePixmap();
 }
 
-void TKSelectColorAction::defaultColor()
+void TTDESelectColorAction::defaultColor()
 {
    m_pCurrentColor = d->defaultColor;
    emit activated();
 }
 
-void TKSelectColorAction::setDefaultColor(const TQColor &_col)
+void TTDESelectColorAction::setDefaultColor(const TQColor &_col)
 {
     d->defaultColor=_col;
 }
 
-void TKSelectColorAction::updatePixmap()
+void TTDESelectColorAction::updatePixmap()
 {
   for( int id = 0; id < containerCount(); ++id ) {
     TQWidget* w = container(id);
-    if ( w->inherits("KToolBar") ) {
-      TQWidget* r = static_cast<KToolBar*>(w)->getWidget(itemId(id));
-      if ( r->inherits("TKToolBarButton") ) {
-        updatePixmap(static_cast<TKToolBarButton*>(r));
+    if ( w->inherits("TDEToolBar") ) {
+      TQWidget* r = static_cast<TDEToolBar*>(w)->getWidget(itemId(id));
+      if ( r->inherits("TTDEToolBarButton") ) {
+        updatePixmap(static_cast<TTDEToolBarButton*>(r));
       }
     }
     else if(w->inherits(TQPOPUPMENU_OBJECT_NAME_STRING) ) {
-        TQPixmap pix =iconSet(KIcon::Small).pixmap(TQIconSet::Automatic,TQIconSet::Active);
+        TQPixmap pix =iconSet(TDEIcon::Small).pixmap(TQIconSet::Automatic,TQIconSet::Active);
   if ( pix.isNull() )
       return;
         TQPainter p(&pix);
@@ -191,7 +191,7 @@ void TKSelectColorAction::updatePixmap()
   }
 }
 
-void TKSelectColorAction::updatePixmap(TKToolBarButton* b)
+void TTDESelectColorAction::updatePixmap(TTDEToolBarButton* b)
 {
   if (!b)
     return;
@@ -219,7 +219,7 @@ void TKSelectColorAction::updatePixmap(TKToolBarButton* b)
   b->setPixmap(pix);
 }
 
-void TKSelectColorAction::setCurrentColor( const TQColor& color )
+void TTDESelectColorAction::setCurrentColor( const TQColor& color )
 {
     if ( color == m_pCurrentColor )
         return;
@@ -229,12 +229,12 @@ void TKSelectColorAction::setCurrentColor( const TQColor& color )
   updatePixmap();
 }
 
-void TKSelectColorAction::setActiveColor( const TQColor& color )
+void TTDESelectColorAction::setActiveColor( const TQColor& color )
 {
   m_pStandardColor->setActiveColor(color);
 }
 
-void TKSelectColorAction::selectColorDialog()
+void TTDESelectColorAction::selectColorDialog()
 {
     TQColor c = color();
 
@@ -260,19 +260,19 @@ void TKSelectColorAction::selectColorDialog()
 }
 
 // Called when activating the menu item
-void TKSelectColorAction::slotActivated()
+void TTDESelectColorAction::slotActivated()
 {
-  //kdDebug() << "TKSelectColorAction::slotActivated" << endl;
+  //kdDebug() << "TTDESelectColorAction::slotActivated" << endl;
   selectColorDialog();
 }
 
-void TKSelectColorAction::activate()
+void TTDESelectColorAction::activate()
 {
   emit colorSelected(m_pCurrentColor);
   emit activated();
 }
 
-void TKSelectColorAction::panelColorSelected( const TQColor& color )
+void TTDESelectColorAction::panelColorSelected( const TQColor& color )
 {
   m_pMenu->hide();
   setCurrentColor(color);
@@ -280,7 +280,7 @@ void TKSelectColorAction::panelColorSelected( const TQColor& color )
   activate();
 }
 
-void TKSelectColorAction::panelReject()
+void TTDESelectColorAction::panelReject()
 {
   m_pMenu->hide();
 }
